"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.integrationCreateFailureResult = exports.integrationCreateResultSchema = exports.klevuIntegrationCreateResultSchema = exports.klevuIntegrationCreateFailureResultSchema = exports.klevuIntegrationCreateSuccessResultSchema = exports.algoliaIntegrationCreateResultSchema = exports.algoliaIntegrationCreateFailureResultSchema = exports.algoliaIntegrationCreateSuccessResultSchema = exports.integrationFailureResultBase = exports.errorCodeSchema = exports.integrationCreateConfigSchema = exports.klevuIntegrationSettingsSchema = exports.algoliaIntegrationSettingsSchema = exports.integrationSettingsBaseSchema = void 0;
const zod_1 = require("zod");
const error_messages_1 = require("../error-messages");
exports.integrationSettingsBaseSchema = zod_1.z.object({
    epccConfig: zod_1.z.object({
        host: zod_1.z.union([zod_1.z.string(), zod_1.z.literal("eu-west"), zod_1.z.literal("us-east")]),
        clientId: zod_1.z.string(),
        clientSecret: zod_1.z.string(),
    }),
});
exports.algoliaIntegrationSettingsSchema = exports.integrationSettingsBaseSchema.merge(zod_1.z.object({
    name: zod_1.z.literal("algolia"),
    appId: zod_1.z.string().min(1),
    adminApiKey: zod_1.z.string().min(1),
}));
exports.klevuIntegrationSettingsSchema = exports.integrationSettingsBaseSchema.merge(zod_1.z.object({
    name: zod_1.z.literal("klevu"),
    apiKey: zod_1.z.string().min(1),
    searchUrl: zod_1.z.string().min(1),
}));
exports.integrationCreateConfigSchema = zod_1.z.discriminatedUnion("name", [
    exports.algoliaIntegrationSettingsSchema,
    exports.klevuIntegrationSettingsSchema,
]);
exports.errorCodeSchema = zod_1.z.enum(error_messages_1.errorCodes);
exports.integrationFailureResultBase = zod_1.z.object({
    success: zod_1.z.literal(false),
    reason: zod_1.z.string(),
    error: zod_1.z.instanceof(Error).optional(),
});
exports.algoliaIntegrationCreateSuccessResultSchema = zod_1.z.object({
    success: zod_1.z.literal(true),
    name: zod_1.z.literal("algolia"),
    result: zod_1.z.any(),
});
exports.algoliaIntegrationCreateFailureResultSchema = exports.integrationFailureResultBase.merge(zod_1.z.object({
    name: zod_1.z.literal("algolia"),
    code: exports.errorCodeSchema,
}));
exports.algoliaIntegrationCreateResultSchema = zod_1.z.discriminatedUnion("success", [
    exports.algoliaIntegrationCreateSuccessResultSchema,
    exports.algoliaIntegrationCreateFailureResultSchema,
]);
exports.klevuIntegrationCreateSuccessResultSchema = zod_1.z.object({
    success: zod_1.z.literal(true),
    name: zod_1.z.literal("klevu"),
    result: zod_1.z.any(),
});
exports.klevuIntegrationCreateFailureResultSchema = exports.integrationFailureResultBase.merge(zod_1.z.object({
    name: zod_1.z.literal("klevu"),
    code: zod_1.z.enum(error_messages_1.klevuErrorCodes),
}));
exports.klevuIntegrationCreateResultSchema = zod_1.z.discriminatedUnion("success", [
    exports.klevuIntegrationCreateSuccessResultSchema,
    exports.klevuIntegrationCreateFailureResultSchema,
]);
exports.integrationCreateResultSchema = zod_1.z.union([
    exports.algoliaIntegrationCreateResultSchema,
    exports.klevuIntegrationCreateResultSchema,
]);
exports.integrationCreateFailureResult = zod_1.z.discriminatedUnion("name", [
    exports.algoliaIntegrationCreateFailureResultSchema,
    exports.klevuIntegrationCreateFailureResultSchema,
]);
