import { v4 as uuidv4 } from "uuid";
import { errorMessages, klevuErrorMessages, } from "./error-messages";
export function handleCatchError(err) {
    return err instanceof Error ? err : new Error("Unknown error occurred");
}
export function processAsIntegrationHubErrorResponse(result) {
    var _a, _b;
    if (result.error) {
        return {
            success: false,
            error: new Error(`${(_a = result.error) === null || _a === void 0 ? void 0 : _a.name} - ${(_b = result.error) === null || _b === void 0 ? void 0 : _b.message}`),
        };
    }
    return {
        success: false,
        error: new Error("No error information was provided."),
    };
}
export function createWebhookSecretKey() {
    return uuidv4();
}
export function didRequestFail(response) {
    return !response.success;
}
export function resolveErrorResponse(code, error) {
    return {
        success: false,
        name: "algolia",
        code,
        reason: errorMessages[code],
        error,
    };
}
export function resolveKlevuErrorResponse(code, error) {
    return {
        success: false,
        name: "klevu",
        code,
        reason: klevuErrorMessages[code],
        error,
    };
}
export function resolveIntegrationHubBaseUrl(region) {
    return `https://${resolveIntegrationHubHost(region)}.elasticpathintegrations.com/api/`;
}
export function resolveIntegrationHubHost(region) {
    switch (region) {
        case "eu-west":
            return "eu-west-1";
        case "us-east":
            return "us-east-2";
        default:
            return "us-east-2";
    }
}
