import { __awaiter } from "tslib";
import { handleCatchError, processAsIntegrationHubErrorResponse, } from "../helpers";
import { GetUserInfoDocument, UserInfoFragment, } from "../integration-hub-queries/user-queries";
import { useFragment } from "../../codegen/gql";
export function getUserInfo(urqlClient) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield gqlGetUserInfo(urqlClient);
            const userInfoFragment = response.data &&
                useFragment(UserInfoFragment, response.data.authenticatedUser);
            if (userInfoFragment !== null && userInfoFragment !== undefined) {
                return {
                    success: true,
                    data: userInfoFragment,
                };
            }
            return processAsIntegrationHubErrorResponse(response);
        }
        catch (err) {
            return {
                success: false,
                error: handleCatchError(err),
            };
        }
    });
}
function gqlGetUserInfo(urqlClient) {
    return __awaiter(this, void 0, void 0, function* () {
        return urqlClient.query(GetUserInfoDocument, {}).toPromise();
    });
}
