import { z } from "zod";
import { errorCodes, klevuErrorCodes } from "../error-messages";
export const integrationSettingsBaseSchema = z.object({
    epccConfig: z.object({
        host: z.union([z.string(), z.literal("eu-west"), z.literal("us-east")]),
        clientId: z.string(),
        clientSecret: z.string(),
    }),
});
export const algoliaIntegrationSettingsSchema = integrationSettingsBaseSchema.merge(z.object({
    name: z.literal("algolia"),
    appId: z.string().min(1),
    adminApiKey: z.string().min(1),
}));
export const klevuIntegrationSettingsSchema = integrationSettingsBaseSchema.merge(z.object({
    name: z.literal("klevu"),
    apiKey: z.string().min(1),
    searchUrl: z.string().min(1),
}));
export const integrationCreateConfigSchema = z.discriminatedUnion("name", [
    algoliaIntegrationSettingsSchema,
    klevuIntegrationSettingsSchema,
]);
export const errorCodeSchema = z.enum(errorCodes);
export const integrationFailureResultBase = z.object({
    success: z.literal(false),
    reason: z.string(),
    error: z.instanceof(Error).optional(),
});
export const algoliaIntegrationCreateSuccessResultSchema = z.object({
    success: z.literal(true),
    name: z.literal("algolia"),
    result: z.any(),
});
export const algoliaIntegrationCreateFailureResultSchema = integrationFailureResultBase.merge(z.object({
    name: z.literal("algolia"),
    code: errorCodeSchema,
}));
export const algoliaIntegrationCreateResultSchema = z.discriminatedUnion("success", [
    algoliaIntegrationCreateSuccessResultSchema,
    algoliaIntegrationCreateFailureResultSchema,
]);
export const klevuIntegrationCreateSuccessResultSchema = z.object({
    success: z.literal(true),
    name: z.literal("klevu"),
    result: z.any(),
});
export const klevuIntegrationCreateFailureResultSchema = integrationFailureResultBase.merge(z.object({
    name: z.literal("klevu"),
    code: z.enum(klevuErrorCodes),
}));
export const klevuIntegrationCreateResultSchema = z.discriminatedUnion("success", [
    klevuIntegrationCreateSuccessResultSchema,
    klevuIntegrationCreateFailureResultSchema,
]);
export const integrationCreateResultSchema = z.union([
    algoliaIntegrationCreateResultSchema,
    klevuIntegrationCreateResultSchema,
]);
export const integrationCreateFailureResult = z.discriminatedUnion("name", [
    algoliaIntegrationCreateFailureResultSchema,
    klevuIntegrationCreateFailureResultSchema,
]);
