import { __awaiter } from "tslib";
import { createEpccClient } from "../../integration-hub";
import { updateEpPaymentGateway } from "./update-gateway";
export function setupEPPaymentsPaymentGateway(sourceInput, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const { epccConfig: { host: epccHost, clientId: epccClientId, clientSecret: epccClientSecret, }, epPaymentsStripeAccountId, } = sourceInput;
            const epccClient = createEpccClient({
                host: epccHost,
                client_id: epccClientId,
                client_secret: epccClientSecret,
            });
            const updateResult = yield updateEpPaymentGateway(epccClient, epPaymentsStripeAccountId);
            if (!updateResult.success) {
                logger.debug(`Failed to update ep payment gateway.`);
                return updateResult;
            }
            return updateResult;
        }
        catch (err) {
            const errorStr = `An unknown error occurred: ${err instanceof Error
                ? `${err.name} = ${err.message}`
                : JSON.stringify(err)}`;
            logger.error(errorStr);
            return {
                success: false,
                error: new Error(errorStr),
            };
        }
    });
}
